<p align="center">
  <a href="https://github.com/AlexDemure/gadignore">
    <a href="https://ibb.co/39sRV2np"><img src="https://i.ibb.co/Nd3Tf5M9/logo.png" alt="logo" border="0"></a>
  </a>
</p>

<p align="center">
  CLI tool for quickly generating a .gitignore file for Python projects.
</p>

---

### Installation

```
pip install gadignore
```

### Usage

```sh
gadignore
```
